@@ -26,7 +26,10 @@
 #include <glibmm/i18n.h>
 
 
+#include "sharp/directory.hpp"
+
 #include "debug.hpp"
+#include "gnote.hpp"
 #include "notebuffer.hpp"
 #include "notewindow.hpp"
 
@@ -37,6 +40,8 @@
 
 namespace bugzilla {
 
+  DECLARE_MODULE(BugzillaModule);
+
   BugzillaModule::BugzillaModule()
   {
     ADD_INTERFACE_IMPL(BugzillaNoteAddin);
@@ -70,6 +75,31 @@ namespace bugzilla {
 
   const char * BugzillaNoteAddin::TAG_NAME = "link:bugzilla";
 
+  BugzillaNoteAddin::BugzillaNoteAddin()
+    : gnote::NoteAddin()
+  {
+    const bool is_first_run
+                 = !sharp::directory_exists(images_dir());
+    const std::string old_images_dir
+      = Glib::build_filename(gnote::Gnote::old_note_dir(),
+                             "BugzillaIcons");
+    const bool migration_needed
+                 = is_first_run
+                   && sharp::directory_exists(old_images_dir);
+
+    if (is_first_run)
+      sharp::directory_create(images_dir());
+
+    if (migration_needed)
+      migrate_images(old_images_dir);
+  }
+
+  std::string BugzillaNoteAddin::images_dir()
+  {
+    return Glib::build_filename(gnote::Gnote::conf_dir(),
+                                "BugzillaIcons");
+  }
+
   void BugzillaNoteAddin::initialize()
   {
     if(!get_note()->get_tag_table()->is_dynamic_tag_registered(TAG_NAME)) {
@@ -78,6 +108,22 @@ namespace bugzilla {
     }
   }
 
+  void BugzillaNoteAddin::migrate_images(
+                            const std::string & old_images_dir)
+  {
+    const Glib::RefPtr<Gio::File> src
+      = Gio::File::create_for_path(old_images_dir);
+    const Glib::RefPtr<Gio::File> dest
+      = Gio::File::create_for_path(gnote::Gnote::conf_dir());
+
+    try {
+      sharp::directory_copy(src, dest);
+    }
+    catch (const Gio::Error & e) {
+      DBG_OUT("BugzillaNoteAddin: migrating images: %s",
+              e.what().c_str());
+    }
+  }
 
 
   void BugzillaNoteAddin::shutdown()
@@ -98,18 +144,8 @@ namespace bugzilla {
                                                 guint, guint time)
   {
     DBG_OUT("Bugzilla.OnDragDataReceived");
-    Gdk::ListHandle_AtomString targets = context->get_targets();
-
-    for(Gdk::ListHandle_AtomString::const_iterator iter = targets.begin();
-        iter != targets.end(); ++iter) {
-      
-      std::string atom(*iter);
-      DBG_OUT("atom is %s", atom.c_str());
-      if((atom == "text/uri-list") || (atom == "_NETSCAPE_URL")) {
-        drop_uri_list(context, x, y, selection_data, time);
-        return;
-      }
-    }
+    drop_uri_list(context, x, y, selection_data, time);
+    return;
   }
 
 
