@@ -1,6 +1,7 @@
 /*
  * gnote
  *
+ * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -48,7 +49,6 @@
 #include "recentchanges.hpp"
 #include "utils.hpp"
 #include "xkeybinder.hpp"
-#include "sharp/string.hpp"
 #include "sharp/streamreader.hpp"
 #include "sharp/files.hpp"
 
@@ -343,7 +343,7 @@ namespace gnote {
     about.set_name("Gnote");
     about.set_version(VERSION);
     about.set_logo(utils::get_icon("gnote", 48));
-    about.set_copyright(_("Copyright \xc2\xa9 2009 Debarshi Ray\n"
+    about.set_copyright(_("Copyright \xc2\xa9 2009-2010 Debarshi Ray\n"
                           "Copyright \xc2\xa9 2009 Hubert Figuiere\n"
                           "Copyright \xc2\xa9 2004-2009 the Tomboy original authors."));
     about.set_comments(_("A simple and easy to use desktop "
@@ -487,7 +487,7 @@ namespace gnote {
     }
 
     if(m_open_note && *m_open_note) {
-      if (sharp::string_starts_with(m_open_note, "note://gnote/")) {
+      if (Glib::str_has_prefix(m_open_note, "note://gnote/")) {
         m_open_note_uri = m_open_note;
       }
       else if (sharp::file_exists(m_open_note)) {
