@@ -1,6 +1,7 @@
 /*
  * gnote
  *
+ * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -329,6 +330,9 @@ namespace gnote {
       sigc::mem_fun(*this, &NoteRecentChanges::on_treeview_motion_notify), false);
     m_tree->signal_button_release_event().connect(
       sigc::mem_fun(*this, &NoteRecentChanges::on_treeview_button_released));
+    m_tree->signal_key_press_event().connect(
+      sigc::mem_fun(*this,
+                    &NoteRecentChanges::on_treeview_key_pressed));
     m_tree->signal_drag_data_get().connect(
       sigc::mem_fun(*this, &NoteRecentChanges::on_treeview_drag_data_get));
 
@@ -795,6 +799,19 @@ namespace gnote {
       break;
     case GDK_BUTTON_PRESS:
       if (ev->button == 3) {
+        const Glib::RefPtr<Gtk::TreeSelection> selection
+          = m_tree->get_selection();
+
+        if(selection->get_selected_rows().size() <= 1) {
+          Gtk::TreeViewColumn * col = 0; // unused
+          Gtk::TreePath p;
+          int cell_x, cell_y;            // unused
+          if (m_tree->get_path_at_pos(ev->x, ev->y, p, col,
+                                      cell_x, cell_y)) {
+            selection->unselect_all();
+            selection->select(p);
+          }
+        }
         Gtk::Menu *menu = dynamic_cast<Gtk::Menu*>(
           ActionManager::obj().get_widget("/MainWindowContextMenu"));
         popup_context_menu_at_location (menu, ev->x, ev->y);
@@ -883,6 +900,29 @@ namespace gnote {
     return false;
   }
                 
+  bool NoteRecentChanges::on_treeview_key_pressed(GdkEventKey * ev)
+  {
+    switch (ev->keyval) {
+    case GDK_Menu:
+    {
+      // Pop up the context menu if a note is selected
+      Note::List selected_notes = get_selected_notes();
+      if (!selected_notes.empty()) {
+        ActionManager & manager = ActionManager::obj();
+        Gtk::Menu * const menu
+          = dynamic_cast<Gtk::Menu*>(manager.get_widget(
+                                       "/MainWindowContextMenu"));
+        popup_context_menu_at_location(menu, 0, 0);
+      }
+      break;
+    }
+    default:
+      break;
+    }
+
+    return false; // Let Escape be handled by the window.
+  }
+
   void NoteRecentChanges::popup_context_menu_at_location(Gtk::Menu *menu, int x, int y)
   {
     menu->show_all ();
@@ -902,67 +942,44 @@ namespace gnote {
   // the context menu with the keyboard.
   void NoteRecentChanges::position_context_menu(int & x, int & y, bool & push_in)
   {
-    Gtk::TreeIter iter;
-    Gtk::TreePath dest_path;
-    Glib::RefPtr<Gtk::TreeSelection> selection;
-
     // Set default "return" values
     push_in = false; // not used
     x = 0;
     y = 0;
 
-    selection = m_tree->get_selection();
-    iter = selection->get_selected();
-    if (!iter)
+    Gtk::Widget * const focus_widget = this->get_focus();
+    if (!focus_widget)
+      return;
+    focus_widget->get_window()->get_origin(x, y);
+
+    Gtk::TreeView * const tree = dynamic_cast<Gtk::TreeView*>(
+                                   focus_widget);
+    if (!tree)
+      return;
+    const Glib::RefPtr<Gdk::Window> tree_area
+                                      = tree->get_bin_window();
+    if (!tree_area)
+      return;
+    tree_area->get_origin(x, y);
+
+    const Glib::RefPtr<Gtk::TreeSelection> selection
+                                             = tree->get_selection();
+    const std::list<Gtk::TreePath> selected_rows
+                                     = selection->get_selected_rows();
+    if (selected_rows.empty())
       return;
 
-    dest_path = m_store_sort->get_path (iter);
-
-    int pos_x = 0;
-    int pos_y = 0;
-
-    get_widget_screen_pos (*m_tree, pos_x, pos_y);
+    const Gtk::TreePath & dest_path = selected_rows.front();
+    const std::list<Gtk::TreeViewColumn *> columns
+                                             = tree->get_columns();
     Gdk::Rectangle cell_rect;
-    m_tree->get_cell_area (dest_path, **m_tree->get_columns().begin(), cell_rect);
+    tree->get_cell_area (dest_path, *columns.front(), cell_rect);
 
-    // Add 100 to x so it's not be at the far left
-    x = pos_x + cell_rect.get_x() + 100;
-    y = pos_y + cell_rect.get_y();
+    x += cell_rect.get_x();
+    y += cell_rect.get_y();
   }
 
 
-  // Walk the widget hiearchy to figure out
-  // where to position the context menu.
-  void NoteRecentChanges::get_widget_screen_pos(Gtk::Widget & widget, int & x, int & y)
-  {
-    int widget_x;
-    int widget_y;
-    Gtk::Window *win;
-
-    win = dynamic_cast<Gtk::Window*>(&widget);
-    if (win) {
-      win->get_position (widget_x, widget_y);
-    } 
-    else {
-      get_widget_screen_pos(*widget.get_parent(), x, y);
-
-      // Special case the TreeView because it adds
-      // too much since it's in a scrolled window.
-      if (&widget == m_tree) {
-        widget_x = 2;
-        widget_y = 2;
-      } 
-      else {
-        Gdk::Rectangle widget_rect = widget.get_allocation();
-        widget_x = widget_rect.get_x();
-        widget_y = widget_rect.get_y();
-      }
-    }
-
-    x += widget_x;
-    y += widget_y;
-  }
-
   Note::List NoteRecentChanges::get_selected_notes()
   {
     Note::List selected_notes;
@@ -1064,18 +1081,6 @@ namespace gnote {
       // Allow Escape to close the window
       on_close_window ();
       break;
-    case GDK_Menu:
-    {
-      // Pop up the context menu if a note is selected
-      Note::List selected_notes = get_selected_notes ();
-      if (!selected_notes.empty()) {
-        Gtk::Menu *menu = dynamic_cast<Gtk::Menu*>(ActionManager::obj().get_widget (
-                                                     "/MainWindowContextMenu"));
-        popup_context_menu_at_location (menu, 0, 0);
-      }
-
-      break;
-    }
     default:
       break;
     }
@@ -1434,20 +1439,26 @@ namespace gnote {
   {
     if(ev->button == 3) {
       // third mouse button (right-click)
+      Gtk::TreeViewColumn * col = 0; // unused
+      Gtk::TreePath p;
+      int cell_x, cell_y;            // unused
+      const Glib::RefPtr<Gtk::TreeSelection> selection
+        = m_notebooksTree->get_selection();
+
+      if (m_notebooksTree->get_path_at_pos(ev->x, ev->y, p, col,
+                                           cell_x, cell_y)) {
+        selection->select(p);
+      }
+
       notebooks::Notebook::Ptr notebook = get_selected_notebook ();
       if (!notebook)
         return true; // Don't pop open a submenu
           
-      Gtk::TreePath p;
 
       bool rowClicked = true;
-      Gtk::TreeViewColumn * col = NULL; // unused
-      int cell_x, cell_y;               // unused
       if (m_notebooksTree->get_path_at_pos (ev->x, ev->y, p, col, cell_x, cell_y) == false) {
         rowClicked = false;
       }
-
-      Glib::RefPtr<Gtk::TreeSelection> selection = m_notebooksTree->get_selection();
       if (selection->count_selected_rows () == 0) {
         rowClicked = false;
       }
@@ -1473,15 +1484,12 @@ namespace gnote {
   bool NoteRecentChanges::on_notebooks_key_pressed(GdkEventKey * ev)
   {
     switch (ev->keyval) {
-    case GDK_Escape:
-      // Allow Escape to close the window
-      on_close_window ();
-      break;
     case GDK_Menu:
+    {
       // Pop up the context menu if a notebook is selected
       notebooks::Notebook::Ptr notebook = get_selected_notebook ();
       if (!notebook || std::tr1::dynamic_pointer_cast<notebooks::SpecialNotebook>(notebook))
-        return true; // Don't pop open a submenu
+        break; // Don't pop open a submenu
           
       Gtk::Menu *menu = dynamic_cast<Gtk::Menu *>(ActionManager::obj().get_widget (
                                                     "/NotebooksTreeContextMenu"));
@@ -1489,7 +1497,11 @@ namespace gnote {
 
       break;
     }
-    return false;
+    default:
+      break;
+    }
+
+    return false; // Let Escape be handled by the window.
   }
     
   void NoteRecentChanges::on_note_added_to_notebook (const Note & , 
