@@ -46,6 +46,8 @@ public:
   DateTime & add_days(int days);
   DateTime & add_hours(int hours);
 
+  int day() const;
+  int month() const;
   int year() const;
   int day_of_year() const;
 
@@ -74,6 +76,10 @@ public:
     {
       return m_date.tv_usec;
     }
+  void set_usec(glong _usec) 
+    {
+      m_date.tv_usec = _usec;
+    }
 private:
   // return the string formatted according to strftime
   std::string _to_string(const char * format, struct tm *) const;
